@@ -21,15 +21,29 @@
 #include "AudioFileQT.H"
 #include "AudioFileSnd.H"
 #include "AudioFileFfmpeg.H"
+#include "AudioFileMpeg3.H"
 #include "Resampler.H"
-
+#include <FL/filename.H>
 
 namespace nle
 {
 
 IAudioFile* AudioFileFactory::get( string filename )
 {
-	IAudioFile *af = new AudioFileSnd( filename );
+	IAudioFile *af = 0;
+#ifdef LIBMPEG3
+	const char* ext = fl_filename_ext( filename.c_str() );
+	if ( strcmp( ext, ".TOC" ) == 0 || strcmp( ext, ".toc" ) == 0 ) {
+		af = new AudioFileMpeg3( filename );
+	}
+#endif /* LIBMPEG3 */
+
+	if ( !af || !af->ok() ) {
+		if ( af ) {
+			delete af;
+		}
+		af = new AudioFileSnd( filename );
+	}
 	if ( !af->ok() ) {
 		delete af;
 		af = new AudioFileQT( filename );
