@@ -1,6 +1,7 @@
 		
 #include "Frei0rBoolButton.H"
 #include <FL/Fl_Color_Chooser.H>
+#include "VideoViewGL.H"
 static void frei0r_bool_button_callback( Frei0rBoolButton* o, void* data )
 {
 	o->toggle_value();
@@ -25,6 +26,7 @@ void Frei0rBoolButton::toggle_value()
 	value( !value() );
 	f0r_param_bool bvalue = (double)value();
 	f0r_set_param_value( m_instance, &bvalue, m_param_index );
+	nle::g_videoView->redraw();
 }
 void Frei0rBoolButton::set_instance( f0r_instance_t i, f0r_set_param_value_f s, f0r_get_param_value_f g, int param_index )
 {
