@@ -1,6 +1,7 @@
 		
 #include "Frei0rColorButton.H"
 #include <FL/Fl_Color_Chooser.H>
+#include "VideoViewGL.H"
 static void frei0r_color_button_callback( Frei0rColorButton* o, void* data )
 {
 	o->select_color();
@@ -35,6 +36,7 @@ void Frei0rColorButton::select_color()
 		f0r_set_param_value( m_instance, &colors, m_param_index );
 		color( fl_rgb_color( (uchar)( r * 255 ), (uchar)( g * 255), (uchar)( b * 255 ) ) );
 		labelcolor( fl_contrast( FL_FOREGROUND_COLOR, color() ) );
+		nle::g_videoView->redraw();
 	}
 }
 void Frei0rColorButton::set_instance( f0r_instance_t i, f0r_set_param_value_f s, f0r_get_param_value_f g, int param_index )
