@@ -22,13 +22,14 @@
 #include <sys/stat.h>
 #include <unistd.h>
 #include <cassert>
-
+#include <sstream>
 
 #include <FL/Fl.H>
 #include <FL/Fl_Widget.H>
 #include <FL/Fl_Window.H>
 #include <FL/fl_draw.H>
 #include <FL/Fl_Help_Dialog.H>
+#include <FL/filename.H>
 
 #include "sl/sl.h"
 
@@ -60,6 +61,11 @@
 //#include "HistogramView.H"
 #include "AudioVolumeFilterFactory.H" //TODO: Remove these two includes
 #include "ColorCurveFactory.H"
+#include "AutoTrack.H"
+#include "AutoDragHandler.H"
+#include "VideoFileQT.H"
+#include "VideoFileFfmpeg.H"
+#include "VideoFileMpeg3.H"
 
 #include "audio.xpm"
 #include "video.xpm"
@@ -107,6 +113,26 @@ int TimelineView::handle( int event )
 	int _x = Fl::event_x();
 	int _y = Fl::event_y() - y();
 	switch ( event ) {
+		case FL_MOUSEWHEEL:
+			if ( Fl::event_shift() ) {
+				float new_zoom = SwitchBoard::i()->zoom() - ( Fl::event_dy() * SwitchBoard::i()->zoom() / 2 );
+				if ( new_zoom < 1.0 ) {
+					new_zoom = 1.0;
+				}
+				int64_t new_scroll_position = llrint( ( ( float(_x - LEFT_TRACK_SPACING - x() ) / SwitchBoard::i()->zoom() ) + m_scrollPosition ) ) - llrint( ( ( float(_x - LEFT_TRACK_SPACING - x() ) / new_zoom ) ) );
+				SwitchBoard::i()->zoom( new_zoom );
+				m_scrollPosition = new_scroll_position;
+			} else if ( Fl::event_ctrl() ) {
+				move_cursor( m_stylusPosition + ( Fl::event_dy() * 500000000 / SwitchBoard::i()->zoom() ) );
+			} else {
+				m_scrollPosition += Fl::event_dy();
+				if ( m_scrollPosition < 0 ) {
+					m_scrollPosition = 0;
+				}
+			}
+			adjustScrollbar();
+			redraw();
+			return 1;
 		case FL_PASTE:
 			{
 				Track* t = get_track( _x, _y );
@@ -218,6 +244,21 @@ int TimelineView::handle( int event )
 						}
 					}
 				}
+				/*
+				If Mouse in AutoTrack, return an DragHandler for
+				the Automations.
+				if ( _x > TRACK_SPACING + x() && _x < TRACK_SPACING + x() + 64 )
+				*/
+				Track *tr = get_track( _x, _y );
+				AutoTrack* auttr = 0;
+				if ( tr ) {
+					auttr = dynamic_cast<AutoTrack*>(tr);
+				}
+				if ( auttr && ( Fl::event_button() == FL_LEFT_MOUSE ) ) {
+					Rect rect = get_track_rect( tr );
+					m_dragHandler = new AutoDragHandler( auttr, rect, _x, _y );
+					return 1;
+				}
 				cl = get_clip( _x, _y );
 				VideoClip* vcl = 0;
 				if ( cl ) {
@@ -353,11 +394,6 @@ int TimelineView::handle( int event )
 				if ( cl && g_ui->automationsMode() == 1 && audioClip ) {
 					Rect r = get_clip_rect( cl, true );
 					m_dragHandler = audioClip->onMouseDown( r, _x, _y, FL_SHIFT & Fl::event_state() );
-					/*if ( FL_SHIFT & Fl::event_state() ) {
-						m_dragHandler = new ShiftAutomationDragHandler( cl, get_clip_rect( cl, true ), _x, _y );
-					} else {
-						m_dragHandler = new AutomationDragHandler( cl, get_clip_rect( cl, true ), 0, _x, _y );
-					}*/
 					return 1;
 				} else if ( cl ) {
 					if ( _x < get_screen_position( cl->position(), cl->track()->stretchFactor() ) + 8 ) {
@@ -574,6 +610,43 @@ void TimelineView::draw()
 			}
 		}
 
+		if ( AutoTrack* autt = dynamic_cast<AutoTrack*>(track) ) {
+			int64_t scr_clip_x = x_coord;
+			int64_t scr_clip_y = y_coord;
+			int64_t scr_clip_w = w_size;
+			int64_t scr_clip_h = track->h();
+			Rect rect( scr_clip_x, scr_clip_y, scr_clip_w, scr_clip_h );
+			auto_node* nodes = autt->getAutomationPoints();
+
+			float stretchF = (float)NLE_TIME_BASE;
+			fl_color( FL_RED );
+			if ( nodes ) {
+				int y =(int)( y_coord + ( ( track->h() - 10 ) * ( 1.0 - nodes->y ) ) + 5 );
+				fl_line( x_coord, y, g_timelineView->get_screen_position( nodes->x, stretchF ), y );
+			}
+			for ( ; nodes && nodes->next; nodes = nodes->next ) {
+				int y = (int)( rect.y + ( ( track->h() - 10 ) * ( 1.0 - nodes->y ) ) + 5 );
+				int y_next = (int)( rect.y + ( ( track->h() - 10 ) * ( 1.0 - nodes->next->y ) ) + 5 );
+				fl_line( g_timelineView->get_screen_position( nodes->x, stretchF ),
+						y,
+						g_timelineView->get_screen_position( nodes->next->x, stretchF ),
+						y_next );
+			}
+			if ( nodes ) {
+				int y =(int)( y_coord + ( ( track->h() - 10 ) * ( 1.0 - nodes->y ) ) + 5 );
+				fl_line( g_timelineView->get_screen_position( nodes->x, stretchF ), y, x_coord + w_size, y );
+			}
+			nodes = autt->getAutomationPoints();
+			for ( ; nodes; nodes = nodes->next ) {
+				//consider Trimming
+				int x;
+				int y = (int)( rect.y + ( ( track->h() - 10 ) * ( 1.0 - nodes->y ) ) );
+				x = g_timelineView->get_screen_position( nodes->x, stretchF );
+				fl_draw_box( FL_UP_BOX, x, y, 10, 10, FL_RED );
+			}
+
+		}
+
 		fl_pop_clip();
 		y_coord += TRACK_SPACING + i->track->h();
 	}
@@ -932,6 +1005,43 @@ void TimelineView::updateEffectDisplay()
 		g_ui->m_effectMenu->deactivate();
 		return;
 	}
+	VideoClip* vidclip = dynamic_cast<VideoClip*>( m_selectedClips->clip );
+	if ( vidclip ) {
+		string interlacing = "none";
+		if ( vidclip->interlacing() == INTERLACE_PROGRESSIVE ) {
+			interlacing = "progressive";
+		} else if ( vidclip->interlacing() == INTERLACE_TOP_FIELD_FIRST ) {
+			interlacing = "top field first";
+		} else if ( vidclip->interlacing() == INTERLACE_BOTTOM_FIELD_FIRST ) {
+			interlacing = "bottom field first";
+		}
+		string aspect;
+		frame_struct frame;
+		guess_aspect( vidclip->w(), vidclip->h(), &frame );
+		stringstream aspectstream;
+		aspectstream << frame.pixel_aspect_ratio;
+		aspect = aspectstream.str();
+		string decoder = "none";
+		if ( dynamic_cast<VideoFileQT*>(vidclip->file()) ) {
+			decoder = "libquicktime";
+		} 
+#ifdef AVCODEC
+		else if ( dynamic_cast<VideoFileFfmpeg*>(vidclip->file()) ) {
+			decoder = "ffmpeg";
+		}
+#endif /* AVCODEC */
+#ifdef LIBMPEG3
+		 else if ( dynamic_cast<VideoFileMpeg3*>(vidclip->file()) ) {
+			decoder = "libmpeg3";
+		}
+#endif /* LIBMPEG3 */
+		string framerate;
+		stringstream frameratestream;
+		
+		frameratestream << ( (float)NLE_TIME_BASE / (float)vidclip->file()->ticksPerFrame() );
+		framerate = frameratestream.str();
+		g_ui->activate_clip( fl_filename_name(vidclip->filename().c_str()), vidclip->filename().c_str(), decoder.c_str(), framerate.c_str(), aspect.c_str(), interlacing.c_str() );
+	}
 	FilterClip* vc = dynamic_cast<FilterClip*>( m_selectedClips->clip );
 	if ( !vc ) {
 		g_ui->m_effectMenu->deactivate();
