@@ -20,6 +20,7 @@
 #include <cstring>
 
 #include <lqt.h>
+#include <lqt_version.h>
 #include <colormodels.h>
 
 #include "VideoFileQT.H"
@@ -110,7 +111,6 @@ VideoFileQT::VideoFileQT( string filename )
 #endif
 	m_interlace_mode = m_framestruct.interlace_mode;
 
-	int aw, ah;
 	guess_aspect( m_framestruct.w, m_framestruct.h, &m_framestruct );
 
 	m_filename = filename;
@@ -147,7 +147,11 @@ void VideoFileQT::read( unsigned char** rows, int w, int h )
 }
 void VideoFileQT::seek( int64_t position )
 {
-	quicktime_set_video_position( m_qt, position / m_ticksPerFrame, 0 );
+	int64_t p = position / m_ticksPerFrame;
+	if ( p >= quicktime_video_length( m_qt, 0 ) ) {
+		p = quicktime_video_length( m_qt, 0 ) - 1;
+	}
+	quicktime_set_video_position( m_qt, p, 0 );
 }
 int64_t VideoFileQT::ticksPerFrame()
 {
