@@ -32,6 +32,13 @@ typedef enum {
 	RENDER_DEFAULT
 } render_strategy_t;
 
+typedef enum {
+	INTERLACE_PROGRESSIVE = 0,
+	INTERLACE_TOP_FIELD_FIRST = 1,
+	INTERLACE_BOTTOM_FIELD_FIRST = 2,
+	INTERLACE_DEVIDED_FIELDS = 3 /* Top Frame is first */
+} interlace_state;
+
 typedef struct
 {
 	int x, y, w, h;
@@ -43,10 +50,20 @@ typedef struct
 	bool has_alpha_channel;
 	bool cacheable;
 	render_strategy_t render_strategy;
-	float aspect;
+	float pixel_aspect_ratio;
 	int pixel_w;
 	int pixel_h;
-	int analog_blank; // Should be 10 pixels for 720x576
+	int interlace_mode;
+	bool first_field; // should be true if first field is to be displayed
+	int scale_x;
+	int scale_y;
+	int crop_left;
+	int crop_right;
+	int crop_top;
+	int crop_bottom;
+	int tilt_x;
+	int tilt_y;
+	bool dirty;
 } frame_struct;
 
 } /* namespace nle */
