@@ -90,6 +90,7 @@ int main( int argc, char** argv )
 	cout << "When submitting a BUG report, or SUPPORT request, please include the following information:" << endl;
 	cout << "----8<-----------------------" << endl;
 	cout << "Libquicktime Version: " << LQT_VERSION << endl;
+	cout << "Libquicktime API Version: " << (LQT_CODEC_API_VERSION & 0xffff) << endl;
 #ifdef AVCODEC
 	cout << "libavcodec Version: " << LIBAVCODEC_IDENT<< endl;
 	cout << "libavformat Version: " << LIBAVFORMAT_IDENT << endl;
@@ -148,6 +149,7 @@ int main( int argc, char** argv )
 /*	nui.special_clips->add("Inkscape Title", nle::PL_VIDEO_SRC, "src:builtin:InkscapeClip" );*/
 	nui.special_clips->add("Volume Automations", nle::PL_AUDIO_FILTER, "filter:builtin:VolumeAutomations" );
 	nui.special_clips->add("Color Curves", nle::PL_VIDEO_EFFECT, "effect:builtin:ColorCurves" );
+	nui.special_clips->add("Node Compositing", nle::PL_VIDEO_EFFECT, "effect:builtin:NodeFilter" );
 
 /*	nle::ScaleCropTiltFilterFactory SCTFilterFactory;
 	nui.special_clips->add(SCTFilterFactory.name(), nle::PL_VIDEO_EFFECT, SCTFilterFactory.identifier() );*/
@@ -192,7 +194,6 @@ int main( int argc, char** argv )
 	Fl::background( 93, 93, 114 );
 	Fl::foreground( 255, 255, 255 );
 	Fl::set_color( FL_BLACK, 200, 200, 200 );
-
 //	Fl::lock();
 	
 	nle::g_audio_codec_info = lqt_query_registry( 1, 0, 1, 0 );
